.. |br| raw:: html

  <br/>

References
----------
.. [OmniPath] Türei, D., Valdeolivas, A. *et al.* (2020), |br|
    *Integrated intra- and intercellular signaling knowledge for multicellular omics analysis*, |br|
    `bioRxiv 2020.08.03.221242 <https://doi.org/10.1101/2020.08.03.221242>`__.

.. [OmniPath16] Türei, D., Korcsmáros, T. & Saez-Rodriguez, J. (2016), |br|
    *OmniPath: guidelines and gateway for literature-curated signaling pathway resources.*, |br|
    `Nat Methods 13, 966–967 <https://doi.org/10.1038/nmeth.4077>`__.
